@@ -15,6 +15,12 @@ for (iln = 0; iln < len; iln++){
 }
 netscape= (ver.charAt(iln+1).toUpperCase() != "C");
 
+function toggle_all_(regex,state_object)
+{
+    state = document.getElementById(state_object).checked;
+    chk_set_all(regex, state);
+}
+
 
 /* Toggle checkbox that matches regex */
 function chk_set_all(regex,value)
@@ -257,6 +263,12 @@ function adjust_height(e) {
 				suggested= inner_height-230;
 			}
 		}
+
+		/* Reduce height if a list footer is set */
+		if(document.getElementById("t_scrollfoot")){
+			suggested = suggested -20;
+		}
+
 		document.getElementById("d_scrollbody").style.height=suggested+"px";
 	}
 	return true;
@@ -303,7 +315,7 @@ function adjust_width(e) {
 		var width= parseInt(window.innerWidth);
 
 		// Resize the body cells
-		var diff= width-div_width-470;
+		var diff= width-div_width-200;
 		
 		// window has been upscaled
 		if(div_width+diff>=600) {
@@ -329,4 +341,36 @@ function adjust_width(e) {
 	}
 }
 
+
+
+/* Set focus to first valid input field 
+		avoid IExplorer warning about hidding or disabled fields 
+*/
+function focus_field()
+{	
+		var i 		= 0;
+		var e 		= 0;
+		var found = false; 
+		var element_name = "";
+		var element =null;
+
+		while(focus_field.arguments[i] && !found){
+
+				var tmp = document.getElementsByName(focus_field.arguments[i]);	
+				for(e = 0 ; e < tmp.length ; e ++ ){
+
+						if(tmp[e].disabled != true &&  tmp[e].type != "none" && tmp[e].type != "hidden" ){
+								found = true;
+								element = tmp[e];
+						}
+				}
+				i++;
+		}
+
+		if(element && found){
+				element.blur();		
+				element.focus();		
+		}
+}
+
 // vim:ts=2:syntax
