@@ -32,6 +32,12 @@ function displayLogin()
     if(isset($_POST["username"])){
       $username= $_POST["username"];
     }
+
+    /* Place ie workaround if needed */
+    if (isset($config->data['MAIN']['IE_PNG_WORKAROUND']) && preg_match("/true/i",$config->data['MAIN']['IE_PNG_WORKAROUND'])){
+      $smarty->assign('ieworkaround', 1);
+    }
+
     $smarty->assign ('date', gmdate("D, d M Y H:i:s"));
     $smarty->assign ('username', $username);
     $smarty->assign ('personal_img', get_template_path('images/personal.png'));
@@ -46,7 +52,7 @@ function displayLogin()
 
     /* Displasy SSL mode warning? */
     if ($ssl != "" && $config->data['MAIN']['WARNSSL'] == 'true'){
-      $smarty->assign ("ssl", "<b>"._("Warning").":<\/b> "._("Session will not be encrypted.")." <a style=\"color:red;\" href=\"$ssl\"><b>"._("Enter SSL session")."<\/b></a>!");
+      $smarty->assign ("ssl", "<b>"._("Warning").":</b> "._("Session will not be encrypted.")." <a style=\"color:red;\" href=\"$ssl\"><b>"._("Enter SSL session")."</b></a>!");
     } else {
       $smarty->assign ("ssl", "");
     }
@@ -70,7 +76,7 @@ function displayLogin()
       $smarty->assign("errors", $_SESSION['errors']);
     }
     if ($error_collector != ""){
-      $smarty->assign("php_errors", $error_collector."</div>");
+      $smarty->assign("php_errors", preg_replace("/%BUGBODY%/",$error_collector_mailto,$error_collector)."</div>");
     } else {
       $smarty->assign("php_errors", "");
     }
@@ -97,14 +103,11 @@ $_SESSION['errorsAlreadyPosted']= array();
 $_SESSION['LastError']          = "";
 
 /* Check if we need to run setup */
-if (!file_exists(CONFIG_DIR."/gosa.conf")){
+if (!file_exists(CONFIG_DIR."/".CONFIG_FILE)){
   header("location:setup.php");
   exit();
 }
 
-/* Reset errors */
-$_SESSION['errors']= "";
-
 /* Check for java script */
 if(isset($_POST['javascript']) && $_POST['javascript'] == "true") {
   $_SESSION['js']= TRUE;
@@ -112,14 +115,14 @@ if(isset($_POST['javascript']) && $_POST['javascript'] == "true") {
   $_SESSION['js']= FALSE;
 }
 
-/* Check if gosa.conf is accessible */
-if (!is_readable(CONFIG_DIR."/gosa.conf")){
-  echo sprintf(_("GOsa configuration %s/gosa.conf is not readable. Aborted."), CONFIG_DIR);
+/* Check if CONFIG_FILE is accessible */
+if (!is_readable(CONFIG_DIR."/".CONFIG_FILE)){
+  echo sprintf(_("GOsa configuration %s/%s is not readable. Aborted."), CONFIG_DIR,CONFIG_FILE);
   exit();
 }
 
 /* Parse configuration file */
-$config= new config(CONFIG_DIR."/gosa.conf", $BASE_DIR);
+$config= new config(CONFIG_DIR."/".CONFIG_FILE, $BASE_DIR);
 $_SESSION['DEBUGLEVEL']= $config->data['MAIN']['DEBUGLEVEL'];
 if ($_SERVER["REQUEST_METHOD"] != "POST"){
   @DEBUG (DEBUG_CONFIG, __LINE__, __FUNCTION__, __FILE__, $config->data, "config");
@@ -143,13 +146,7 @@ if (!(is_dir($smarty->compile_dir) && is_writable($smarty->compile_dir))){
 /* Check for old files in compile directory */
 clean_smarty_compile_dir($smarty->compile_dir);
 
-/* Language setup */
-if ($config->data['MAIN']['LANG'] == ""){
-  $lang= get_browser_language();
-} else {
-  $lang= $config->data['MAIN']['LANG'];
-}
-$lang.=".UTF-8";
+$lang= get_browser_language();
 putenv("LANGUAGE=");
 putenv("LANG=$lang");
 setlocale(LC_ALL, $lang);
@@ -214,17 +211,28 @@ if ($_SERVER["REQUEST_METHOD"] == "POST" && isset($_POST['login'])){
     $config->data['MAIN']['SCHEMA_CHECK'] = "true";
   }
   if(isset($config->data['MAIN']['SCHEMA_CHECK'])&&preg_match("/true/i",$config->data['MAIN']['SCHEMA_CHECK'])){
-    require_once("functions_setup.inc");
-    if(!is_schema_readable($config->current['SERVER'],$config->current['ADMIN'],$config->current['PASSWORD'])){
+    $recursive = (isset($config->current['RECURSIVE']) && $config->current['RECURSIVE'] == "true");
+    $tls =       (isset($config->current['TLS'])       && $config->current['TLS'] == "true");
+
+    if(!count($ldap->get_objectclasses())){
+
       print_red(_("GOsa cannot retrieve information about the installed schema files. Please make sure, that this is possible."));
       displayLogin();
       exit();
     }else{
-      $str = (schema_check($config->current['SERVER'],$config->current['ADMIN'],$config->current['PASSWORD'],0,TRUE));
+ 
+      $cfg = array(); 
+      $cfg['admin']     = $config->current['ADMIN'];
+      $cfg['password']  = $config->current['PASSWORD'];
+      $cfg['connection']= $config->current['SERVER'];
+      $cfg['tls']       = $tls;
+  
+      $str = check_schema($cfg,isset($config->current['RFC2307BIS']) && preg_match("/(true|yes|on|1)/i",$config->current['RFC2307BIS']));
+
       $checkarr = array();
       foreach($str as $tr){
-        if(isset($tr['needonstartup'])){
-          print_red($tr['msg']."<br>"._("Your ldap setup contains old schema definitions. Please re-run the setup."));
+        if(isset($tr['IS_MUST_HAVE']) && !$tr['STATUS']){
+          print_red($tr['MSG']."<br>"._("Your ldap setup contains old schema definitions. Please re-run the setup."));
           displayLogin();
           exit();
         }
@@ -259,7 +267,7 @@ if ($_SERVER["REQUEST_METHOD"] == "POST" && isset($_POST['login'])){
 
     /* Login as user, initialize user ACL's */
     $ui= ldap_login_user($username, $_POST["password"]);
-    if ($ui === NULL || $ui == 0){
+    if ($ui === NULL || !$ui ){
       $message= _("Please check the username/password combination.");
       $smarty->assign ('nextfield', 'password');
       gosa_log ("Authentication failed for user \"$username\"");
@@ -277,6 +285,11 @@ if ($_SERVER["REQUEST_METHOD"] == "POST" && isset($_POST['login'])){
       $config->make_idepartments();
       $_SESSION['config']= $config;
 
+      /* Take care about zend.ze1_compatiblity_mode */
+      if (ini_get("zend.ze1_compatibility_mode") != 0){
+        $_SESSION['PHP4COMPATIBLE']= TRUE;
+      }
+
       /* are we using accountexpiration */
       if((isset($config->data['MAIN']['ACCOUNT_EXPIRATION'])) && 
           preg_match('/true/i', $config->data['MAIN']['ACCOUNT_EXPIRATION'])){
@@ -362,8 +375,8 @@ if ($error_collector != ""){
 } else {
   $smarty->assign("php_errors", "");
 }
-displayLogin();
 
+displayLogin();
 
 // vim:tabstop=2:expandtab:shiftwidth=2:filetype=php:syntax:ruler:
 ?>
